from uuid import UUID

UUID_SERVICE = UUID("{0000180a-0000-1000-8000-00805f9b34fb}")
MODEL_NUMBER = UUID("{00002a24-0000-1000-8000-00805f9b34fb}")
FIRMWARE_VERSION = UUID("{00002a26-0000-1000-8000-00805f9b34fb}")
HARDWARE_VERSION = UUID("{00002a27-0000-1000-8000-00805f9b34fb}")
SOFTWARE_VERSION = UUID("{00002a28-0000-1000-8000-00805f9b34fb}")
MANUFACTURER_NAME = UUID("{00002a29-0000-1000-8000-00805f9b34fb}")

DEVICE_NAME = UUID("{b85fa07a-9382-4838-871c-81d045dcc2ff}")
DEVICE_STATUS = UUID("{528b80e8-c47a-4c0a-bdf1-916a7748f412}")

AUTH = UUID("{4cad343a-209a-40b7-b911-4d9b3df569b2}")

HUMIDITY = UUID("{7c4adc01-2f33-11e7-93ae-92361f002671}")
LIGHT_VOC = UUID("{7c4adc02-2f33-11e7-93ae-92361f002671}")
CONSTANT_SPEED = UUID("{7c4adc03-2f33-11e7-93ae-92361f002671}")
TIMER = UUID("{7c4adc04-2f33-11e7-93ae-92361f002671}")
AIRING = UUID("{7c4adc05-2f33-11e7-93ae-92361f002671}")
PAUSE = UUID("{7c4adc06-2f33-11e7-93ae-92361f002671}")
BOOST = UUID("{7c4adc07-2f33-11e7-93ae-92361f002671}")
TEMPORARY_SPEED = UUID("{7c4adc08-2f33-11e7-93ae-92361f002671}")
